%define major	1.7
%define libname	%mklibname git2_ %{major}
%define devname	%mklibname git2 -d

Name:		libgit2
Version:	1.7.2
Release:	%mkrel 1
Summary:	A C implementation of the Git core methods as a library
Group:		System/Libraries
License:	GPLv2 with exceptions
URL:		https://libgit2.org/
Source0:	https://github.com/libgit2/libgit2/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:	cmake
BuildRequires:	http-parser-devel
#BuildRequires: libxdiff-devel
BuildRequires:	pkgconfig(openssl)
BuildRequires:	python3
BuildRequires:	pkgconfig(zlib)
BuildRequires:	pkgconfig(libssh2)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libpcre2-8)
BuildRequires:	ninja-build

Provides:	bundled(libxdiff)

%description
libgit2 is a portable, pure C implementation of the Git core methods
provided as a re-entrant linkable library with a solid API, allowing
you to write native speed custom Git applications in any language
with bindings.

%package -n %{libname}
Summary:	A C implementation of the Git core methods as a library
Group:		System/Libraries
Provides:	%{name} = %{version}-%{release}

%description -n %{libname}
libgit2 is a portable, pure C implementation of the Git core methods
provided as a re-entrant linkable library with a solid API, allowing
you to write native speed custom Git applications in any language
with bindings.

%package -n %{devname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{devname}
The %{devname} package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q
%autopatch -p1

# Remove VCS files from examples
find examples -name ".gitignore" -delete

# Don't run "online" tests
sed -i '/-sonline/s/^/#/' tests/libgit2/CMakeLists.txt

# Remove bundled libraries (except libxdiff)
pushd deps
find . -maxdepth 1 -not -name xdiff -exec rm -rf {} ';'
popd

%build
%cmake  \
  -GNinja \
  -DREGEX_BACKEND=pcre2 \
  -DBUILD_CLI=OFF \
  -DUSE_HTTP_PARSER=system \
  -DUSE_SHA1=HTTPS \
  -DUSE_HTTPS=OpenSSL \
  -DUSE_NTLMCLIENT=OFF \
  -DUSE_SSH=ON \
  %{nil}
%cmake_build

%install
%cmake_install

%ifarch %{ix86} x86_64
%check
%ctest
%endif

%files -n %{libname}
%doc COPYING
%{_libdir}/libgit2.so.%{major}{,.*}

%files -n %{devname}
%doc docs examples AUTHORS README.md
%{_libdir}/libgit2.so
%{_libdir}/pkgconfig/libgit2.pc
%{_includedir}/git2.h
%{_includedir}/git2/


%changelog
* Wed Mar 13 2024 ns80 <ns80> 1.7.2-1.mga10
+ Revision: 2049790
- new version 1.7.2 for CVE-2024-24577 (mga#30633)

* Tue Jan 09 2024 daviddavid <daviddavid> 1.7.1-1.mga10
+ Revision: 2029291
- new version: 1.7.1

* Wed Jul 13 2022 kekepower <kekepower> 1.3.2-1.mga9
+ Revision: 1868720
- Update to version 1.3.2

* Tue Mar 29 2022 umeabot <umeabot> 1.3.0-2.mga9
+ Revision: 1833195
- Mageia 9 Mass Rebuild

* Sun Jan 02 2022 wally <wally> 1.3.0-1.mga9
+ Revision: 1766248
- new version 1.3.0
- new lib major 1.3

* Sat Oct 02 2021 wally <wally> 1.1.1-2.mga9
+ Revision: 1747450
- rebuild for openssl 3.0.0

* Sun Aug 08 2021 luigiwalser <luigiwalser> 1.1.1-1.mga9
+ Revision: 1740232
- 1.1.1

* Wed Dec 30 2020 luigiwalser <luigiwalser> 1.1.0-1.mga8
+ Revision: 1666135
- 1.1.0
- lib major is now 1.1

* Sat Jul 18 2020 joequant <joequant> 1.0.1-2.mga8
+ Revision: 1607180
- turn off test for no network
- disable tests because of arm
- add pcre2
- update to 1.0.1

* Fri Apr 10 2020 daviddavid <daviddavid> 0.28.5-1.mga8
+ Revision: 1565971
- new version: 0.28.5 (mga#26464)

* Thu Feb 27 2020 daviddavid <daviddavid> 0.28.4-2.mga8
+ Revision: 1550937
- don't run "online" tests
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Fri Dec 13 2019 kekepower <kekepower> 0.28.4-1.mga8
+ Revision: 1466290
- Update to version 0.28.4

* Mon Oct 28 2019 tv <tv> 0.28.3-1.mga8
+ Revision: 1456239
- new release

* Sat Jun 29 2019 wally <wally> 0.28.2-1.mga8
+ Revision: 1416087
- new version 0.28.2

* Sat Apr 20 2019 wally <wally> 0.28.1-1.mga7
+ Revision: 1393738
- new version 0.28.1
- new lib major 28

* Sat Nov 10 2018 bcornec <bcornec> 0.27.7-1.mga7
+ Revision: 1329299
- Update to 0.27.7 (mga#22813)

* Fri Oct 26 2018 bcornec <bcornec> 0.27.5-1.mga7
+ Revision: 1325580
- update to upstream 0.27.5 to fix mga#22813

* Sun Sep 23 2018 umeabot <umeabot> 0.27.4-2.mga7
+ Revision: 1298869
- Mageia 7 Mass Rebuild

* Thu Aug 09 2018 guillomovitch <guillomovitch> 0.27.4-1.mga7
+ Revision: 1250803
- new version 0.27.4

* Fri Aug 03 2018 guillomovitch <guillomovitch> 0.27.3-1.mga7
+ Revision: 1247013
- new version 0.27.3

* Thu Jul 05 2018 guillomovitch <guillomovitch> 0.27.2-1.mga7
+ Revision: 1242006
- new version 0.27.2
+ kekepower <kekepower>
- Update to version 0.27.1. Fixes CVE-2018-11235.

* Tue Mar 27 2018 kekepower <kekepower> 0.27.0-1.mga7
+ Revision: 1212754
- Update to 0.27.0

* Sat Aug 05 2017 guillomovitch <guillomovitch> 0.26.0-2.mga7
+ Revision: 1136096
- rebuild for latest openssl

* Mon Jul 17 2017 tv <tv> 0.26.0-1.mga7
+ Revision: 1124384
- bump major
- new release

* Wed Mar 22 2017 ovitters <ovitters> 0.25.0-1.mga6
+ Revision: 1094370
- bump major
- new version 0.25.0

* Tue Jan 10 2017 wally <wally> 0.24.6-1.mga6
+ Revision: 1080838
- new version 0.24.6 to fix CVE-2016-856[8,9] (mga#19553)

* Sun Nov 13 2016 akien <akien> 0.24.1-2.mga6
+ Revision: 1066938
- Provide libgit2-devel (used by cargo synced with Fedora)

* Mon May 02 2016 tv <tv> 0.24.1-1.mga6
+ Revision: 1008654
- new release

* Tue Mar 15 2016 tv <tv> 0.24.0-1.mga6
+ Revision: 990762
- bump major
- new release

* Wed Mar 02 2016 umeabot <umeabot> 0.23.4-2.mga6
+ Revision: 983569
- Rebuild for openssl

* Sat Feb 20 2016 tv <tv> 0.23.4-1.mga6
+ Revision: 972351
- new release

* Mon Feb 15 2016 umeabot <umeabot> 0.23.2-2.mga6
+ Revision: 961003
- Mageia 6 Mass Rebuild

* Thu Sep 24 2015 tv <tv> 0.23.2-1.mga6
+ Revision: 883225
- new release

* Tue Aug 04 2015 wally <wally> 0.23.1-1.mga6
+ Revision: 861043
- new version 0.23.1
- new libmajor 23
- drop unneeded patches

* Sun Jun 21 2015 ovitters <ovitters> 0.22.2-1.mga6
+ Revision: 838223
- fix major and br
- new version 0.22.2

* Wed Oct 15 2014 umeabot <umeabot> 0.21.1-3.mga5
+ Revision: 744920
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.21.1-2.mga5
+ Revision: 681487
- Mageia 5 Mass Rebuild

* Sun Aug 10 2014 wally <wally> 0.21.1-1.mga5
+ Revision: 661399
- new version 0.21.1

* Sun Jun 22 2014 wally <wally> 0.21.0-1.mga5
+ Revision: 638700
- new version 0.21.0
- new lib major 21

* Tue Feb 04 2014 wally <wally> 0.20.0-1.mga5
+ Revision: 582084
- clean .spec a bit

* Fri Jan 10 2014 tv <tv> 0.20.0-1.mga4
+ Revision: 566119
- imported package libgit2


* Mon Jan 06 2014 Thierry Vignaud <tv@mageia.org> 0.19.0-1.mga4
- initial release (based on FC)
- temporary build with internal xdiff
